tessellate package
==================

Subpackages
-----------

.. toctree::

    tessellate.utils

Submodules
----------

tessellate\.cli module
----------------------

.. automodule:: tessellate.cli
    :members:
    :undoc-members:
    :show-inheritance:

tessellate\.tessellate module
-----------------------------

.. automodule:: tessellate.tessellate
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: tessellate
    :members:
    :undoc-members:
    :show-inheritance:
